@@ -7,7 +7,7 @@
 # Date: 2010.03.23
 #
 # File: espeakcaller.py
-# Version: 0.4
+# Version: 0.5
 # 
 # Special thanks to: 
 #    Original eSpeak project: http://espeak.sourceforge.net/
@@ -132,9 +132,10 @@ class eSpeakCaller(QtGui.QMainWindow):
              
         pdFile = open(cfgTmp, 'w+')
         pdFile.write(self.GeteSpeakCommand() + '\n')
-        pdFile.write(self.ui.lineSay.displayText() + '\n')
-        pdFile.write(self.ui.lineUnCaller.displayText() + '\n')
-        pdFile.write(self.ui.lineBlCaller.displayText() + '\n')
+        
+        pdFile.write(unicode(self.ui.lineSay.displayText()).encode("utf-8") + '\n')
+        pdFile.write(unicode(self.ui.lineUnCaller.displayText()).encode("utf-8") + '\n')
+        pdFile.write(unicode(self.ui.lineBlCaller.displayText()).encode("utf-8") + '\n')
         if self.ui.checkNickname.isChecked():
             pdFile.write("1" + '\n')
         else:
@@ -151,7 +152,7 @@ class eSpeakCaller(QtGui.QMainWindow):
     def GeteSpeakCommand(self):
         # Damn eSpeak supports lot of langueages
         sLang=['',' -ven',' -ven-us',' -ven-sc',' -vaf',' -vbs',' -vca',' -vcs',' -vde',' -vel',' -veo',' -ves',' -ves-la',' -vfi',' -vfr',' -vhr',' -vhu',' -vit',' -vku',' -vlv',' -vpl',' -vpt',' -vpt-pt',' -vro',' -vsk',' -vsr',' -vsv',' -vsw',' -vta',' -vtr',' -vzh']
-        tmpCmd = "espeak -m " + sLang[self.ui.comboLang.currentIndex()] + " "
+        tmpCmd = "/usr/bin/espeak -m " + sLang[self.ui.comboLang.currentIndex()] + " "
         tmpCmd = tmpCmd + "-a " + str(self.ui.sliVolume.value()) + " "
         tmpCmd = tmpCmd + "-p " + str(self.ui.sliPitch.value()) + " "
         tmpCmd = tmpCmd + "-s " + str(self.ui.sliSpeed.value()) + " "
@@ -166,11 +167,13 @@ class eSpeakCaller(QtGui.QMainWindow):
         if self.ui.lineBlCaller.displayText() != "":
             tmpName = self.ui.lineBlCaller.displayText()
         else:
-            tmpName = self.ui.lineSay.displayText().replace("%name%", "Test")
+            tmpName = self.ui.lineSay.displayText().replace("%name%", "Test-name")
+            tmpName = tmpName.replace("%first%", "first name")
+            tmpName = tmpName.replace("%last%", "last name")
 
-        tmpS = self.GeteSpeakCommand().replace("%text%", tmpName)#.decode('utf-8')
+        tmpS = self.GeteSpeakCommand().replace("%text%", tmpName)
         #print tmpS
-        subprocess.Popen(unicode(tmpS).encode("utf-8"), shell=True)
+        subprocess.Popen(unicode(tmpS).encode("utf-8"), shell=True) #.encode("utf-8")
         
         
     # Apply settings
